import { CodeableConcept, Coding, uri } from 'fhir';
import { ElementBuilder } from './element-builder';
/** A class representing a FHIR CodeableConceptBuilder */
export declare class CodeableConceptBuilder extends ElementBuilder {
    /**
     * The CodeableConcept being built
     * @private
     * @type { CodeableConcept }
     * @ignore
     */
    protected element: CodeableConcept;
    /**
     * Creates a new CodeableConceptBuilder
     */
    constructor();
    /**
     * Sets a copy of an existing codeableConcept for this builder to allow for manipulation,
     * If no argument is provided, a new CodeableConcept will be generated
     * @param { CodeableConcept } codeableConcept - the codeableConcept to be set
     * @returns { CodeableConceptBuilder } The builder
     * @override
     */
    use(codeableConcept?: CodeableConcept): this;
    /**
     * Returns the text-field of the CodeableConcept
     * @returns The text-field
     */
    getText(): string | undefined;
    /**
     * Sets the text-field of the CodeableConcept
     * If no argument is provided, the field will be removed
     * @param { string } text - The value to be set in the text-field
     * @returns { CodeableConceptBuilder } - This CodeableConceptBuilder
     */
    setText(text?: string): this;
    /**
     * Returns either the coding identified by the provided system from the coding-array or the entire coding array, if no id is provided
     * @param { uri } [system] The system of the coding to retrieve (if applicable)
     * @returns { Coding | undefined | Coding[] } The coding or the coding-array
     */
    getCoding(): Coding[];
    getCoding(system: uri): Coding | undefined;
    /**
     * Sets the resource's coding-array to the provided array
     * If no argument is provided, the field will be removed
     * @param { Coding[] } codings The array to be set as the resource's coding array
     * @returns the Builder
     */
    setCoding(coding?: Coding[]): this;
    /**
     * Adds a coding to the CodeableConcept
     * @param { Coding } coding - The coding to add
     * @returns { CodeableConceptBuilder} The builder
     */
    addCoding(coding: Coding): this;
    /**
     * Creates a new CodeableConcept
     * @returns { CodeableConcept } The codeableConcept
     * @override
     */
    protected make(): CodeableConcept;
    /**
     * Builds and returns the CodeableConcept
     * @override
     * @returns { CodeableConcept } - the CodeableConcept
     */
    build(): CodeableConcept;
}
