import { Identifier, IdentifierUse, CodeableConcept, Period, Reference } from 'fhir';
import { ElementBuilder } from './element-builder';
/** Class representing a FHIR Identifier builder */
export declare class IdentifierBuilder extends ElementBuilder {
    /**
     * The identifier being built
     * @private
     * @type { Identifier }
     * @ignore
     */
    protected element: Identifier;
    /**
     * Create a new FHIR IdentifierBuilder
     */
    constructor();
    /**
     * Sets a copy of an existing identifier for this builder to allow for manipulation
     * If no argument is provided, a new Identifier will be generated
     * @param { Identifier } identifier - the identifier to be set
     * @returns { IdentifierBuilder } The builder
     * @override
     */
    use(identifier?: Identifier): this;
    /**
     * Returns the use-field of the Identifier
     * @returns { IdentifierUse } The use-field
     */
    getUse(): IdentifierUse | undefined;
    /**
     * Sets the use-field of the Identifier
     * If no argument is provided, the field will be removed
     * @param { IdentifierUse } use - The value to be set in the use-field
     * @returns { IdentifierBuilder } - The builder
     */
    setUse(use?: IdentifierUse): this;
    /**
     * Returns the type-field of the Identifier
     * @returns { CodeableConcept } The type-field
     */
    getType(): CodeableConcept | undefined;
    /**
     * Sets the type-field of the Identifier
     * If no argument is provided, the field will be removed
     * @param { CodeableConcept } type - The value to be set in the type-field
     * @returns { IdentifierBuilder } - The builder
     */
    setType(type?: CodeableConcept): this;
    /**
     * Returns the system-field of the Identifier
     * @returns { string } The system-field
     */
    getSystem(): string | undefined;
    /**
     * Sets the system-field of the Identifier
     * If no argument is provided, the field will be removed
     * @param { string } system - The value to be set in the system-field
     * @returns { IdentifierBuilder } - The builder
     */
    setSystem(system?: string): this;
    /**
     * Returns the value-field of the Identifier
     * @returns { string } The value-field
     */
    getValue(): string | undefined;
    /**
     * Sets the value-field of the Identifier
     * If no argument is provided, the field will be removed
     * @param { string } value - The value to be set in the value-field
     * @returns { IdentifierBuilder } - The builder
     */
    setValue(value?: string): this;
    /**
     * Returns the period-field of the Identifier
     * @returns { Period } The period-field
     */
    getPeriod(): Period | undefined;
    /**
     * Sets the period-field of the Identifier
     * If no argument is provided, the field will be removed
     * @param { Period } period - The value to be set in the period-field
     * @returns { IdentifierBuilder } - The builder
     */
    setPeriod(period?: Period): this;
    /**
     * Returns the assigner-field of the Identifier
     * @returns { Reference } The assigner-field
     */
    getAssigner(): Reference | undefined;
    /**
     * Sets the assigner-field of the Identifier
     * If no argument is provided, the field will be removed
     * @param { Reference } assigner - The value to be set in the assigner-field
     * @returns { IdentifierBuilder } - The builder
     */
    setAssigner(assigner?: Reference): this;
    /**
     * Returns whether or not the identifier provided as an argument is in conflict with the identifier used in the builder
     * @param { Identifier } identifier The identifier to test for conflict
     * @returns { boolean } Whether it is in conflict
     * @override
     */
    conflictsWith(identifier: Identifier): boolean;
    /**
     * Creates a new Identifier
     * @returns { Identifier } The identifier
     * @override
     */
    protected make(): Identifier;
    /**
     * Returns the identifier
     * @returns { Identifier } the identifier
     * @override
     */
    build(): Identifier;
}
