import { PlanDefinition, PlanDefinitionAction, id, uri, canonical } from 'fhir';
import { DomainResourceBuilder } from './domain-resource-builder';
/**
 * Class representing a FHIR PlanDefinition builder
 * FIXME: Incomplete
 */
export declare class PlanDefinitionBuilder extends DomainResourceBuilder {
    /**
     * The PlanDefinition that is being built
     * @protected
     * @type { PlanDefinition }
     * @ignore
     */
    protected resource: PlanDefinition;
    /**
     * Creates a new FHIR PlanDefinitionBuilder
     */
    constructor();
    /**
     * Sets a copy of an existing plandefinition for this PlanDefinitionBuilder to allow for manipulating, or interacting with, the
     * plandefinition through this PlanDefinitionBuilder
     * If no argument is provided, a new PlanDefinition will be generated
     * @param { PlanDefinition } plandefinition - The plandefinition to set
     * @returns { PlanDefinitionBuilder } This PlanDefinitionBuilder
     * @override
     */
    use(planDefinition?: PlanDefinition): this;
    /**
     * Checks if a Questionnaire with a specific canonical is in the PlanDefinition.
     * @param canonical The canonical of the Questionnaire to check for
     * @returns { boolean } A boolean value indicating whether the Questionnaire is there or not.
     */
    has(canonical: canonical): boolean;
    /**
     * Returns the url-field of the PlanDefinition
     * @returns { uri } The url-field
     */
    getUrl(): uri | undefined;
    /**
     * Sets the url-field of the PlanDefinition
     * If no argument is provided, the field will be removed
     * @param { uri } url - The value to be set in the url-field
     * @returns { PlanDefinitionBuilder } - This PlanDefinitionBuilder
     */
    setUrl(url?: uri): this;
    /**
     * Returns the version-field of the PlanDefinition
     * @returns { string } The version-field
     */
    getVersion(): string | undefined;
    /**
     * Sets the version-field of the Coding
     * If no argument is provided, the field will be removed
     * @param { string } version - The value to be set in the version-field
     * @returns { PlanDefinitionBuilder } - This PlanDefinitionBuilder
     */
    setVersion(version?: string): this;
    /**
     * Returns either the planDefintitionAction identified by the provided id from the action-array or the entire action-array, if no id is provided
     * @returns { PlanDefinitionAction[] } The planDefintitionAction identified by the provided id or the action-array
     */
    getAction(): PlanDefinitionAction[];
    getAction(id: id): PlanDefinitionAction | undefined;
    /**
     * Sets the action-array to the provided array
     * If no argument is provided, the field will be removed
     * @param { PlanDefinitionAction[] } action The array to be set as the action-array
     * @returns the Builder
     */
    setAction(action?: PlanDefinitionAction[]): this;
    /**
     * Adds the action provided as an argument to the resource's action-array
     * @param { PlanDefinitionAction } action The action to be added to the action-array
     * @returns the Builder
     */
    addAction(action: PlanDefinitionAction): this;
    /**
     * Creates an ISO-string for current time
     * @returns { string } An ISO-string for current time
     * @ignore
     */
    _generateIsoDate(): string;
    /**
     * Make a new object that implements a FHIR PlanDefinition
     * @returns { PlanDefinition } - an object that implements FHIR PlanDefinition
     * @override
     */
    protected make(): PlanDefinition;
    /**
     * Builds and returns the plandefinition
     * @returns { PlanDefinition } - the plandefinition
     * @override
     */
    build(): PlanDefinition;
}
