import { Basic, dateTime, Reference, Extension, canonical } from 'fhir';
import { DomainResourceBuilder } from './domain-resource-builder';
/**
 * Class representing a FHIR ThresholdSet builder
 */
export declare class ThresholdSetBuilder extends DomainResourceBuilder {
    /**
     * The ThresholdSet that is being built
     * @protected
     * @type { Basic }
     * @ignore
     */
    protected resource: Basic;
    /**
     * Creates a new FHIR ThresholdSetBuilder
     */
    constructor();
    /**
     * Sets a copy of an existing thresholdSet for this ThresholdSetBuilder to allow for manipulating, or interacting with, the
     * thresholdSet through this ThresholdSetBuilder
     * If no argument is provided, a new ThresholdSet will be generated
     * @param { ThresholdSet } thresholdSet - The thresholdSet to set
     * @returns { ThresholdSetBuilder } The builder
     * @override
     */
    use(thresholdSet?: Basic): this;
    /**
     * Returns the version of the ThresholdSet
     * @returns { string } The version
     */
    getVersion(): string | undefined;
    /**
     * Sets the version of the ThresholdSet
     * If no argument is provided, the field will be removed
     * @param { string } version - The version
     * @returns { ThresholdSetBuilder } - The builder
     */
    setVersion(system?: string): this;
    /**
     * Returns the status of the ThresholdSet
     * @returns { string } The status
     */
    getStatus(): ThresholdSetStatus | undefined;
    /**
     * Sets the status of the ThresholdSet
     * If no argument is provided, the field will be removed
     * @param { string } status - The version
     * @returns { ThresholdSetBuilder } - The builder
     */
    setStatus(status?: ThresholdSetStatus): this;
    /**
     * Returns the dateTime the thresholdSet was approved
     * @returns { dateTime } The approvalDate
     */
    getApprovalDate(): dateTime | undefined;
    /**
     * Sets the dateTime the thresholdSet was approved
     * If no argument is provided, the field will be removed
     * @param { dateTime } approvalDate - The approvalDate
     * @returns { ThresholdSetBuilder } - The builder
     */
    setApprovalDate(approvalDate?: dateTime): this;
    /**
     * Returns a reference to the practitioner who approved the thresholdSet
     * @returns { Reference } The reference to the approving practitioner
     */
    getApprovingPractitioner(): Reference | undefined;
    /**
     * Sets a reference to the practitioner who approved the thresholdSet
     * If no argument is provided, the field will be removed
     * @param { Reference } approvingPractitioner - The reference to the approving practitioner
     * @returns { ThresholdSetBuilder } - The builder
     */
    setApprovingPractitioner(approvingPractitioner?: Reference): this;
    /**
     * Returns a reference or canonical reference to the resource to which this thresholdSet applies
     * @returns { canonical | Reference } The reference to the resource to which this thresholdSet applies
     */
    getAppliesTo(): canonical | Reference | undefined;
    /**
     * Sets a reference or canonical reference to the resource, to which this thresholdSet applies
     * If no argument is provided, the field will be removed
     * @param { canonical | Reference } appliesTo - The reference or canonical reference to the resource, to which this thresholdSet applies
     * @returns { ThresholdSetBuilder } - The builder
     */
    setAppliesTo(appliesTo?: canonical | Reference): this;
    /**
     * Returns an array of thresholds in the form of extensions
     * @returns { Extension[] } The array of thresholds as extensions
     */
    getThreshold(): Extension[];
    /**
     * Sets the threshold array of the thresholdSet
     * If no argument is provided, the field will be removed
     * @param { Extension[] } threshold - The thresholdArray
     * @returns { ThresholdSetBuilder } - The builder
     */
    setThreshold(threshold?: Extension[]): this;
    /**
     * Adds a threshold to the threshold array of the thresholdSet
     * @param { Extension } threshold - The threshold to add to the threshold-array
     * @returns { ThresholdSetBuilder } - The builder
     */
    addThreshold(threshold: Extension): this;
    /**
     * Returns whether or not the thresholdSet provided as an argument is in conflict with the thresholdSet used in the builder
     * @param { Basic } thresholdSet The thresholdSet to test for conflict
     * @returns { boolean } Whether it is in conflict
     * @override
     */
    conflictsWith(thresholdSet: Basic): boolean;
    /**
     * Creates an ISO-string for current time
     */
    _generateIsoDate(): string;
    /**
     * Make a new object that implements a FHIR ThresholdSet
     * @returns { ThresholdSet } - an object that implements FHIR ThresholdSet
     * @override
     */
    protected make(): Basic;
    /**
     * Builds and returns the plandefinition
     * @returns { ThresholdSet } - the plandefinition
     * @override
     */
    build(): Basic;
}
/**
 * All possible values of ThresholdSet.status
 */
declare type ThresholdSetStatus = 'draft' | 'active' | 'retired' | 'unknown';
export {};
