import { PlanDefinitionAction, canonical, uri } from 'fhir'
import { BackboneElementBuilder } from './backbone-element-builder'

/**
 * Class representing a FHIR BackboneElement builder
 * FIXME: Incomplete
 */
export class PlanDefinitionActionBuilder extends BackboneElementBuilder {
  /**
   * The PlanDefinitionAction that is being built
   * @protected
   * @type { PlanDefinitionAction }
   * @ignore
   */
  protected element: PlanDefinitionAction

  /**
   * Creates a new FHIR PlanDefinitionActionBuilder
   */
  public constructor() {
    super()
    this.element = this.make()
  }

  /**
   * Sets a copy of an existing PlanDefinitionAction for this PlandefinitionActionBuilder to allow for manipulating, or interacting with, the
   * planDefinitionAction through this PlandefinitionActionBuilder
   * If no argument is provided, a new PlanDefinitionAction will be generated
   * @param { PlanDefinitionAction } action - The planDefinitionAction to set
   * @returns { PlandefinitionActionBuilder } The builder
   * @override
   */
  public use(action?: PlanDefinitionAction): this {
    this.element = action ? { ...action } : this.make()
    return this
  }

  /**
   * Returns the definitionCanonical-field of the planDefinitionAction
   * @returns { canonical } The code-field
   */
  public getDefinitionCanonical(): canonical | undefined {
    return this.element.definitionCanonical
  }

  /**
   * Sets the definitionCanonical-field of the planDefinitionAction
   * If no argument is provided, the field will be removed
   * @param { canonical } canonical - The value to be set in the definitionCanonical-field
   * @returns { PlanDefinitionActionBuilder } - The builder
   */
  public setDefinitionCanonical(canonical?: canonical): this {
    canonical
      ? (this.element.definitionCanonical = canonical)
      : delete this.element.definitionCanonical
    return this
  }

  /**
   * Returns the definitionUri-field of the planDefinitionAction
   * @returns { uri } The definitionUri-field
   */
  public getDefinitionUri(): uri | undefined {
    return this.element.definitionUri
  }

  /**
   * Sets the definitionUri-field of the planDefinitionAction
   * If no argument is provided, the field will be removed
   * @param { uri } uri - The value to be set in the definitionUri-field
   * @returns { PlanDefinitionActionBuilder } - The builder
   */
  public setDefinitionUri(uri?: uri): this {
    uri ? (this.element.definitionUri = uri) : delete this.element.definitionUri
    return this
  }

  /**
   * Returns whether or not the planDefintiionAction provided as an argument is in conflict with the planDefinitionAction used in the builder
   * @param { PlanDefinitionAction } action The planDefinitionAction to test for conflict
   * @returns { boolean } Whether it is in conflict
   * @override
   */
  public conflictsWith(action: PlanDefinitionAction) {
    let conflict = super.conflictsWith(action)
    const actionBuilder: PlanDefinitionActionBuilder = new PlanDefinitionActionBuilder().use(
      action
    )

    if (
      this.getDefinitionCanonical() &&
      this.getDefinitionCanonical() === actionBuilder.getDefinitionCanonical()
    ) {
      conflict = true
    }
    if (
      this.getDefinitionUri() &&
      this.getDefinitionUri() === actionBuilder.getDefinitionUri()
    ) {
      conflict = true
    }
    return conflict
  }

  /**
   * Make a new object that implements a FHIR PlanDefinitionAction
   * @returns { PlanDefinitionAction } - an object that implements FHIR PlanDefinitionAction
   * @override
   */
  protected make(): PlanDefinitionAction {
    return {} as PlanDefinitionAction
  }

  /**
   * Builds and returns the planDefinitionAction
   * @returns { PlanDefinitionAction } - the planDefinitionAction
   * @override
   */
  public build(): PlanDefinitionAction {
    return this.element
  }
}
