import { expect } from 'chai'
import { Coding } from 'fhir'
import { CodingBuilder } from '../src'

describe('CodingBuilder', () => {
  it('should be able to build minimal Coding', () => {
    expect(new CodingBuilder().build()).to.eql({})
  })

  it('should be able to accept existing Coding', () => {
    expect(
      new CodingBuilder()
        .use({
          system: 'system',
          code: 'code',
        })
        .build()
    ).to.eql({
      system: 'system',
      code: 'code',
    })
  })

  it('should be able to reset', () => {
    const codingBuilder: CodingBuilder = new CodingBuilder().use({
      system: 'system',
      code: 'code',
    })
    expect(codingBuilder.use().build()).to.eql({})
  })

  it('should be able to set system-field', () => {
    expect(new CodingBuilder().setSystem('system').build()).to.eql({
      system: 'system',
    })
  })

  it('should be able to unset system-field', () => {
    const codingBuilder: CodingBuilder = new CodingBuilder().use({
      system: 'system',
    })

    expect(codingBuilder.setSystem().build()).to.eql({})
  })

  it('should be able to return system-field', () => {
    expect(new CodingBuilder().use({ system: 'system' }).getSystem()).to.eql(
      'system'
    )
  })

  it('should be able to set version-field', () => {
    expect(new CodingBuilder().setVersion('1.0.0').build()).to.eql({
      version: '1.0.0',
    })
  })

  it('should be able to unset version-field', () => {
    const codingBuilder: CodingBuilder = new CodingBuilder().use({
      version: '1.0.0',
    })

    expect(codingBuilder.setVersion().build()).to.eql({})
  })

  it('should be able to return version-field', () => {
    expect(new CodingBuilder().use({ version: '1.0.0' }).getVersion()).to.eql(
      '1.0.0'
    )
  })

  it('should be able to set code-field', () => {
    expect(new CodingBuilder().setCode('code').build()).to.eql({
      code: 'code',
    })
  })

  it('should be able to unset code-field', () => {
    const codingBuilder: CodingBuilder = new CodingBuilder().use({
      code: 'code',
    })

    expect(codingBuilder.setCode().build()).to.eql({})
  })

  it('should be able to return code-field', () => {
    expect(new CodingBuilder().use({ code: 'code' }).getCode()).to.eql('code')
  })

  it('should be able to set display-field', () => {
    expect(new CodingBuilder().setDisplay('display').build()).to.eql({
      display: 'display',
    })
  })

  it('should be able to unset display-field', () => {
    const codingBuilder: CodingBuilder = new CodingBuilder().use({
      display: 'display',
    })

    expect(codingBuilder.setDisplay().build()).to.eql({})
  })

  it('should be able to return display-field', () => {
    expect(new CodingBuilder().use({ display: 'display' }).getDisplay()).to.eql(
      'display'
    )
  })

  it('should be able to set userSelected-field', () => {
    expect(new CodingBuilder().setUserSelected(true).build()).to.eql({
      userSelected: true,
    })
  })

  it('should be able to unset userSelected-field', () => {
    const codingBuilder: CodingBuilder = new CodingBuilder().use({
      userSelected: true,
    })

    expect(codingBuilder.setUserSelected().build()).to.eql({})
  })

  it('should be able to return userSelected-field', () => {
    expect(
      new CodingBuilder().use({ userSelected: true }).getUserSelected()
    ).to.eql(true)
  })
})
