import { expect } from 'chai'
import { PlanDefinitionActionBuilder } from '../src'

describe('PlanDefinitionActionBuilder', () => {
  it('should be able to build minimal PlanDefinitionAction', () => {
    expect(new PlanDefinitionActionBuilder().build()).to.eql({})
  })

  it('should be able to accept existing PlanDefinitionAction', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .use({
          definitionCanonical:
            'canonical://uuid/Questionnaire/f14997cf-e16e-4e4b-8b3a-1f419386f597|1.0.0',
        })
        .build()
    ).to.eql({
      definitionCanonical:
        'canonical://uuid/Questionnaire/f14997cf-e16e-4e4b-8b3a-1f419386f597|1.0.0',
    })
  })

  it('should be able to reset', () => {
    const planDefinitionActionBuilder: PlanDefinitionActionBuilder = new PlanDefinitionActionBuilder().use(
      {
        definitionCanonical:
          'canonical://uuid/Questionnaire/f14997cf-e16e-4e4b-8b3a-1f419386f597|1.0.0',
      }
    )
    expect(planDefinitionActionBuilder.use().build()).to.eql({})
  })

  it('should be able to set definitionCanonical-field', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .setDefinitionCanonical(
          'canonical://uuid/Questionnaire/39268cb0-efb8-4e17-9b5b-9dfc7799495c|1.0.0'
        )
        .build()
    ).to.eql({
      definitionCanonical:
        'canonical://uuid/Questionnaire/39268cb0-efb8-4e17-9b5b-9dfc7799495c|1.0.0',
    })
  })

  it('should be able to unset definitionCanonical-field', () => {
    const codingBuilder: PlanDefinitionActionBuilder = new PlanDefinitionActionBuilder().use(
      {
        definitionCanonical:
          'canonical://uuid/Questionnaire/39268cb0-efb8-4e17-9b5b-9dfc7799495c|1.0.0',
      }
    )

    expect(codingBuilder.setDefinitionCanonical().build()).to.eql({})
  })

  it('should be able to return definitionCanonical-field', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .use({
          definitionCanonical:
            'canonical://uuid/Questionnaire/39268cb0-efb8-4e17-9b5b-9dfc7799495c|1.0.0',
        })
        .getDefinitionCanonical()
    ).to.eql(
      'canonical://uuid/Questionnaire/39268cb0-efb8-4e17-9b5b-9dfc7799495c|1.0.0'
    )
  })

  it('should be able to set definitionUri-field', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .setDefinitionUri('urn:iso:std:iso:11073:10101')
        .build()
    ).to.eql({
      definitionUri: 'urn:iso:std:iso:11073:10101',
    })
  })

  it('should be able to unset definitionUri-field', () => {
    const planDefintionActionBuilder: PlanDefinitionActionBuilder = new PlanDefinitionActionBuilder().use(
      {
        definitionUri: 'urn:iso:std:iso:11073:10101',
      }
    )

    expect(planDefintionActionBuilder.setDefinitionUri().build()).to.eql({})
  })

  it('should be able to return definitionUri-field', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .use({
          definitionUri: 'urn:iso:std:iso:11073:10101',
        })
        .getDefinitionUri()
    ).to.eql('urn:iso:std:iso:11073:10101')
  })

  it('should be able to tell if planDefinitionAction is in conflict with other planDefinitionAction based on id', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .use({
          id: 'id',
        })
        .conflictsWith({
          id: 'id',
        })
    ).to.eql(true)
  })

  it('should be able to tell if planDefinitionAction is in conflict with other planDefinitionAction based on definitionCanonical', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .use({
          definitionCanonical:
            'canonical://uuid/Questionnaire/39268cb0-efb8-4e17-9b5b-9dfc7799495c|1.0.0',
        })
        .conflictsWith({
          definitionCanonical:
            'canonical://uuid/Questionnaire/39268cb0-efb8-4e17-9b5b-9dfc7799495c|1.0.0',
        })
    ).to.eql(true)
  })

  it('should be able to tell if planDefinitionAction is in conflict with other planDefinitionAction based on definitionUri', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .use({
          definitionUri: 'urn:iso:std:iso:11073:10101',
        })
        .conflictsWith({
          definitionUri: 'urn:iso:std:iso:11073:10101',
        })
    ).to.eql(true)
  })

  it('should say two references are not in conflict of one of them contains neither id, definitionCanonical or definitionUri', () => {
    expect(
      new PlanDefinitionActionBuilder()
        .use({
          definitionUri: 'urn:iso:std:iso:11073:10101',
        })
        .conflictsWith({
          title: 'action',
        })
    ).to.eql(false)
  })
})
